delete_vector_statement

Function delete_vector_statement 

pub fn delete_vector_statement(
    table: &str,
    subject_id: Uuid,
    namespace: &str,
) -> SqlStatement
The exact DELETE this store’s delete issues, for a given vector table (ADR-099 B3 r6 structural cut — see stores::entity’s sibling block). table must already be a trusted, sanitized table name (mirrors delete’s own pre-existing lack of a placeholder for table names).